import 'package:encrypted_shared_preferences/encrypted_shared_preferences.dart';
import 'utilities.dart';

class InBaseConfig {
  InBaseConfig(
      {required this.projectId, required this.apiKey, this.showToastOnError});

  int projectId;
  String apiKey;

  /// This will enable or disable the FlutterToastNotifications
  bool? showToastOnError = true;

  EncryptedSharedPreferences encryptedSharedPreferences =
  EncryptedSharedPreferences();

  /// Definition of all sharedPreferenceKeys
  static const String sharedPreferenceProjectId = "waterbase-project-id";
  static const String sharedPreferenceApiKey = "waterbase-api-key";
  static const String sharedPreferenceShowToastKey =
      "waterbase-app-config-show-toast";

  /// This function will save the app credentials in encrypted SharedPreferences
  Future<void> save() async {
    try {
      await encryptedSharedPreferences.setString(
          sharedPreferenceProjectId, projectId.toString());
      await encryptedSharedPreferences.setString(
          sharedPreferenceApiKey, apiKey);
      await encryptedSharedPreferences.setString(
          sharedPreferenceShowToastKey, showToastOnError.toString());
    } catch (e) {
      if (showToastOnError == true) {
        await Utilities.showToast(e.toString());
      }
    }
  }

  /// This will return the saved config
  static Future<InBaseConfig> getConfig() async {
    EncryptedSharedPreferences encryptedSharedPreferences = EncryptedSharedPreferences();

    InBaseConfig inBaseConfig = InBaseConfig(
        projectId: int.parse(await encryptedSharedPreferences
            .getString(sharedPreferenceProjectId)),
        apiKey:
        await encryptedSharedPreferences.getString(sharedPreferenceApiKey),
        showToastOnError: await encryptedSharedPreferences
            .getString(sharedPreferenceShowToastKey) ==
            "true"
            ? true
            : false);

    return inBaseConfig;
  }
}
